@@ -14,6 +14,9 @@ from pybsc.iter_utils import triplewise
 from pybsc.json_utils import load_json
 from pybsc.json_utils import save_json
 
+from pybsc.yaml_utils import load_yaml
+from pybsc.yaml_utils import save_yaml
+
 from pybsc.dict_utils import invert_dict
 
 from pybsc.download import download_file
