@@ -15,11 +15,12 @@ class ClipboardOutput(object):
 
 class stdout_to_clipboard(object):
 
-    def __init__(self):
+    def __init__(self, print_stdout=True):
         sys.stdout.flush()
         self._org_stdout = sys.stdout
         self._old_stdout_fno = os.dup(sys.stdout.fileno())
         self._clip = ClipboardOutput()
+        self.print_stdout = print_stdout
 
     def __enter__(self):
         sys.stdout = self._clip
@@ -29,3 +30,5 @@ class stdout_to_clipboard(object):
         sys.stdout.flush()
         os.dup2(self._old_stdout_fno, 1)
         pyperclip.copy(self._clip.buf)
+        if self.print_stdout:
+            print(self._clip.buf)
